import React, { useEffect, useMemo, useState } from 'react'
import styles from './index.less'
import { Table, Tooltip, message, Button } from 'antd'
import SearchGroup from './components/SearchGroup'
import TablePack from './components/TablePack'
import { GetAccountConfigInfo, GetAccountPageList, getStationListByUserID, GetTableJson } from '../../apis/process'
import { isJson, isObject } from '../../utils/index'
import IconPack from '../widgets/IconPack'

const getFileInfo = (formJson) => {
  let obj = {}
  let json = isJson(formJson) ? JSON.parse(formJson) : {}
  let parent = json?.properties
  if (isObject(parent)) {
    for (let v in parent) {
      let child = parent[v]?.properties
      if (isObject(child)) {
        for (let s in child) {
          obj[s] = child[s]
        }
      }
    }
  }
  return obj
}

const TableRender = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1
  const { accountName } = props
  const [detailShow, setDetailShow] = useState(false)
  const [params, setParams] = useState({ userID: userID, accountName, direction: 'desc', timeField: '录入时间', pageIndex: 1, pageSize: 100 })
  const [loading, setLoading] = useState(false)
  const [config, setConfig] = useState({ webShowFieldGroup: '', formJson: '' })
  const [dataSource, setDataSource] = useState([])

  const fileColumns = useMemo(() => {
    const { webShowFieldGroup, formJson } = config
    let showField = webShowFieldGroup ? webShowFieldGroup.split(',').filter(v => v) : []
    let json = getFileInfo(formJson)
    let array = []
    showField.forEach(v => {
      array.push({
        title: json[v]?.title || v,
        dataIndex: v,
        width: 120,
        ellipsis: true,
        render: (value, r) => {
          let props = { ...json[v], value }
          return (
            <TablePack {...props} />
          )
        }
      })
    })
    return array
  }, [config])

  const columns = useMemo(() => {
    return [
      {
        title: '序号',
        dataIndex: 'r',
        key: 'r',
        width: 50,
        fixed: 'left',
      },
      ...fileColumns,
      {
        title: '操作',
        width: 120,
        fixed: 'right',
        render: (r) => {
          let btns = [
            {
              title: '详情',
              icon: <IconPack.XiangQing />,
            },
            {
              title: '编辑',
              icon: <IconPack.BianJi />,
            },
            {
              title: '删除',
              icon: <IconPack.ShanChu />,
            }
          ]
          return (
            <div>
              {
                btns.map(v => {
                  return (
                    <Button
                      type='link'
                      title={v.title}
                      icon={v.icon}
                      style={{ padding: '0 7px' }}
                      onClick={() => btnsClick(v.title, r)}
                    >
                    </Button>
                  )
                })
              }
            </div>
          )
        }
      }
    ]
  }, [fileColumns])

  const btnsClick = (type, row) => {
    if (['详情', '编辑'].includes(type)) {
      setDetailShow(true)
    }
  }

  const search = (values) => {
    setParams({ ...params, ...values })
    getDataSource({ ...params, ...values })
  }

  const getConfig = async () => {
    const { code, data } = await GetAccountConfigInfo(accountName)
    const res = await GetTableJson(accountName)
    if (code === 0 && res.code === 0) {
      setConfig({ ...data, formJson: res.data })
    }
  }

  const getDataSource = async (param = {}) => {
    setLoading(true)
    const { code, data, msg } = await GetAccountPageList({ ...params, ...param })
    if (code === 0) {
      setDataSource(JSON.parse(data.jsonData))
    } else {
      setDataSource([])
      message.error(msg)
    }
    setLoading(false)
  }

  const getData = () => {
    getConfig()
    getDataSource()
  }

  useEffect(() => {
    getData()
  }, [])

  return (
    <div className={styles.account} style={{ width: '100%', height: '100%' }}>
      <div className={styles.tableRender} style={{ display: !detailShow ? 'block' : 'none' }}>
        <div className={styles.top}>
          <SearchGroup onChange={search} />
        </div>
        <div className={styles.bottom}>
          <Table
            size='small'
            rowKey='ID'
            bordered
            loading={loading}
            columns={columns}
            dataSource={dataSource}
            pagination={false}
            scroll={{ y: 'calc(100% - 50px)' }}
          />
        </div>
      </div>
      <div className={styles.tableDetail} style={{ display: detailShow ? 'block' : 'none' }}>
        <Button
          onClick={() => setDetailShow(false)}
        >
          返回
        </Button>
      </div>
    </div>

  )

}

export default TableRender